import { BigNumber } from "@ethersproject/bignumber";
import { parseUnits } from "@ethersproject/units";
export class BaseToken {
    name;
    symbol;
    addresses = {};
    swapType;
    isETH;
    hash;
    wrapperAddresses = {};
    _decimals = {};
    constructor(args) {
        this.name = args.name;
        this.symbol = args.symbol;
        this.addresses = args.addresses;
        this.swapType = args.swapType;
        this.wrapperAddresses = args.wrapperAddresses ?? {};
        if (typeof args.decimals === "number") {
            for (const [k,] of Object.entries(this.addresses)) {
                this._decimals[k] = args.decimals;
            }
        }
        else {
            this._decimals = args.decimals;
        }
        this.isETH = args.isETH ?? false;
        this.hash = Symbol(this.symbol);
    }
    address(chainId) {
        return this.addresses[chainId] || null;
    }
    wrapperAddress(chainId) {
        return this.wrapperAddresses[chainId] || null;
    }
    decimals(chainId) {
        return this._decimals[chainId] || null;
    }
    isEqual(other) {
        return this.hash === other.hash;
    }
    valueToWei(amt, chainId) {
        let amtStr = BigNumber.from(amt).toString();
        return parseUnits(amtStr, this.decimals(chainId));
    }
    get isWrappedToken() {
        return false;
    }
}
export class WrappedToken extends BaseToken {
    underlyingToken;
    constructor(args) {
        let { underlyingToken, ...tokenArgs } = args;
        super(tokenArgs);
        this.underlyingToken = underlyingToken;
    }
    get isWrappedToken() {
        return true;
    }
}
